@@ -270,7 +270,12 @@ def build_calculator(settings, constraints=list()):
             assert settings["parallel"] > 0, "Calculator `parallel` must be positive."
             parallel = settings["parallel"]
 
-        return presto.calculators.XTBCalculator(charge=charge, multiplicity=multiplicity, gfn=gfn, parallel=parallel, constraints=constraints)
+        xcontrol = None
+        if "xcontrol" in settings:
+            assert isinstance(settings["xcontrol"], str), "Calculator `xcontrol` must be a string."
+            xcontrol = settings["xcontrol"]
+
+        return presto.calculators.XTBCalculator(charge=charge, multiplicity=multiplicity, gfn=gfn, parallel=parallel, constraints=constraints, xcontrol=xcontrol)
 
     else:
         raise ValueError(f"Unknown integrator type {settings['type']}! Allowed options are `oniom`, `xtb`, or `gaussian`.")
